@@ -1,4 +1,3 @@
-/* $Xorg: XKBMisc.c,v 1.4 2000/08/17 19:45:02 cpqbld Exp $ */
 /************************************************************
 Copyright (c) 1993 by Silicon Graphics Computer Systems, Inc.
 
@@ -24,7 +23,6 @@ OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
 THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/X11/XKBMisc.c,v 3.5 2001/10/28 03:32:33 tsi Exp $ */
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
@@ -35,8 +33,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #ifndef XKB_IN_SERVER
 
 #include <stdio.h>
-#define NEED_REPLIES
-#define NEED_EVENTS
 #include "Xlibint.h"
 #include <X11/extensions/XKBproto.h>
 #include <X11/keysym.h>
@@ -46,8 +42,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 #include <stdio.h>
 #include <X11/X.h>
-#define	NEED_EVENTS
-#define	NEED_REPLIES
 #include <X11/Xproto.h>
 #include "misc.h"
 #include "inputstr.h"
@@ -625,7 +619,7 @@ KeySym *	syms;
 	XkbApplyCompatMapToKey(xkb,key,changes);
     }
 
-    if ((xkb->server->vmods!=NULL)&&(xkb->map->modmap!=NULL)&&(changes)&&
+    if ((xkb->map->modmap!=NULL)&&(changes)&&
 	(changes->map.changed&(XkbVirtualModMapMask|XkbModifierMapMask))) {
 	unsigned char		newVMods[XkbNumVirtualMods];
 	register  unsigned 	bit,i;
